<template>
  <div class="commendContent">
    <div class="refresh" @click="refresh">
      <span class="icon iconfont">&#xe606;</span>换一批
    </div>
    <div
      class="commendTabsItem"
      v-for="(item, index) in commendData"
      :key="index"
    >
      <ImageShow :src="item.logoUrl"> </ImageShow>
      <div class="title">{{ item.productName }}</div>
      <div class="des limitRow2">{{ item.description }}</div>
      <price :priceNew="item.priceBase ? item.priceBase : 0"></price>
      <div class="button" @click="buyProduct(item.productName)">立即购买</div>
    </div>
  </div>
</template>

<script>
import price from "@/components/Price.vue";

export default {
  props: {
    commendData: {
      type: Array,
    },
  },
  components: {
    price,
  },
  methods: {
    refresh() {
      this.$emit("refresh");
    },
    buyProduct(productName) {
      this.$router.push({
        path: "/productDetail",
        query: {
          name: productName,
        },
      });
    },
  },
};
</script>

<style lang="scss" scoped>
.commendContent {
  display: flex;
  position: relative;
  width: 1280px;
  margin: 0 auto;

  .commendTabsItem {
    position: relative;
    max-width: 302px;
    height: 332px;
    flex: 1;
    padding-top: 20px;
    text-align: center;
    background-color: #fff;
    margin-right: 24px;

    &:last-child {
      margin-right: 0;
    }

    img {
      height: 96px;
      width: 96px;
    }

    .title {
      margin-top: 20px;
      margin-bottom: 10px;
      font-size: 18px;
      font-weight: 700;
    }

    .des {
      height: 38px;
      margin: 0 20px 20px 20px;
      color: #666666;
      font-size: 14px;
    }

    .button {
      position: absolute;
      bottom: 0;
      right: 0;
      width: 100%;
      height: 40px;
      box-shadow: 0px 2px 8px rgba(0, 43, 106, 0.12);
      color: #ff6a00;
      font-size: 14px;
      font-weight: 700;
      line-height: 40px;
      cursor: pointer;

      &:hover {
        background: linear-gradient(
          90.78deg,
          #ffba4a 0%,
          #ff6a00 20.33%,
          #ff6a00 79.66%,
          #ffba4a 100%
        );
        color: #fff;
      }
    }
  }

  .refresh {
    position: absolute;
    right: 0;
    top: -31px;
    font-size: 14px;
    color: #999999;
    cursor: pointer;

    span {
      margin-right: 6px;
      color: rgb(153, 153, 153);
      font-size: 16px;
    }

    &:hover {
      color: #666;

      span {
        color: #666;
      }
    }
  }
}
</style>